#! /usr/bin/env python3
from ctypes.util import find_library
import os
import numpy as np
import ctypes as ct
import cv2

#change workdirectory for relative generic.xml formats.def and library path
os.chdir(os.path.dirname(os.path.abspath(__file__))+"\\..\\..")

# load library
#linux:
#libir = ct.cdll.LoadLibrary(ct.util.find_library("irdirectsdk"))
#windows:
libir = ct.CDLL("sdk\\x64\\libirimager.dll")


#path to config xml file
pathXml = ct.c_char_p(b'generic.xml')

# init vars
pathFormat = ct.c_char_p()
pathLog = ct.c_char_p(b'logfilename')

palette_width = ct.c_int()
palette_height = ct.c_int()

thermal_width = ct.c_int()
thermal_height = ct.c_int()

# init lib
ret = libir.evo_irimager_usb_init(pathXml, pathFormat, pathLog)
if ret != 0:
        print("error at init")
        exit(ret)

# get thermal image size
libir.evo_irimager_get_thermal_image_size(ct.byref(thermal_width), ct.byref(thermal_height))
print('thermal width: ' + str(thermal_width.value))
print('thermal height: ' + str(thermal_height.value))

# init thermal data container
np_thermal = np.zeros([thermal_width.value * thermal_height.value], dtype=np.uint16)
npThermalPointer = np_thermal.ctypes.data_as(ct.POINTER(ct.c_ushort))

# get palette image size, width is different to thermal image width duo to stride alignment!!!
libir.evo_irimager_get_palette_image_size(ct.byref(palette_width), ct.byref(palette_height))
print('palette width: ' + str(palette_width.value))
print('palette height: ' + str(palette_height.value))

# init image container
np_img = np.zeros([palette_width.value * palette_height.value * 3], dtype=np.uint8)
npImagePointer = np_img.ctypes.data_as(ct.POINTER(ct.c_ubyte))

# capture and display image
while chr(cv2.waitKey(1) & 255) != 'q':
        #get thermal image
        ret = libir.evo_irimager_get_thermal_palette_image(thermal_width, thermal_height, npThermalPointer, palette_width, palette_height, npImagePointer)

        if ret != 0:
                print('error on evo_irimager_get_thermal_palette_image ' + str(ret))
                continue

        #calculate total mean value
        mean_temp = np_thermal.mean()
        mean_temp = mean_temp / 10. - 100

        print('mean temp: ' + str(mean_temp))

        #display palette image
        cv2.imshow('image',np_img.reshape(palette_height.value, palette_width.value, 3))

# clean shutdown
libir.evo_irimager_terminate()